@@ -35,16 +35,17 @@ typedef struct
   const gchar *desc;
 } Description;
 
-static Description method_descriptions [] = {
+static const Description method_descriptions [] = {
   { "dhcp",   N_("Automatic configuration (DHCP)") },
   { "ipv4ll", N_("Local Zeroconf network (IPv4 LL)") },
   { "static", N_("Static IP address") },
 };
 
-static Description key_type_descriptions [] = {
+static const Description key_type_descriptions [] = {
   { "wep-ascii", N_("WEP key (ascii)") },
   { "wep-hex", N_("WEP key (hexadecimal)") },
-  { "wpa-psk", N_("WPA") },
+  { "wpa-psk", N_("WPA Personal") },
+  { "wpa2-psk", N_("WPA2 Personal") },
 };
 
 
@@ -114,21 +115,13 @@ connection_essids_combo_init (GtkComboBoxEntry *combo)
   gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
   g_object_unref (model);
 
-  gtk_cell_layout_clear (GTK_CELL_LAYOUT (combo));
-
   /* add "crypted" renderer */
   renderer = gtk_cell_renderer_pixbuf_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo),
 			      renderer, FALSE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo),
 				 renderer, "pixbuf", 0);
-
-  /* add "essid" renderer */
-  renderer = gtk_cell_renderer_text_new ();
-  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo),
-			      renderer, TRUE);
-  gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo),
-				 renderer, "text", 1);
+  gtk_cell_layout_reorder (GTK_CELL_LAYOUT (combo), renderer, 0);
 
   /* add "quality" renderer */
   renderer = gtk_cell_renderer_progress_new ();
@@ -137,6 +130,7 @@ connection_essids_combo_init (GtkComboBoxEntry *combo)
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo),
 				 renderer, "value", 2);
 
+  /* reuse text cell renderer for the essid */
   gtk_combo_box_entry_set_text_column (combo, 1);
 }
 
@@ -235,8 +229,11 @@ on_essid_list_changed (GstEssidList        *list,
       elem = elem->next;
     }
 
-  g_object_unref (locked);
-  g_object_unref (unlocked);
+  if (locked)
+    g_object_unref (locked);
+
+  if (unlocked)
+    g_object_unref (unlocked);
 }
 #endif
 
@@ -443,10 +440,10 @@ method_to_desc (const Description  descriptions[],
 }
 
 static void
-populate_combo (GtkComboBox  *combo,
-		GList        *list,
-		Description   descriptions[],
-		gint          n_elems)
+populate_combo (GtkComboBox       *combo,
+		GList             *list,
+		const Description  descriptions[],
+		gint               n_elems)
 {
   GtkListStore *store;
   GtkTreeIter iter;
